@@ -4,7 +4,7 @@
 # A rewite of the C canvas example in the GNOME Developer's Information
 
 import gtk
-import gnome.canvas
+import gnomecanvas
 from whrandom import *
 
 def mainquit(*args):
@@ -95,10 +95,10 @@ class CanvasExample:
             y2 = y2 + 10
 
         if (self.generator.random() > .5):
-            type = gnome.canvas.CanvasRect
+            type = gnomecanvas.CanvasRect
         else:
             # Text names should work as well...
-            #type = gnome.canvas.CanvasEllipse
+            #type = gnomecanvas.CanvasEllipse
             type = 'GnomeCanvasEllipse'
 
         w = self.acanvas.root().add(type, x1=x1, y1=y1, x2=x2, y2=y2, 
@@ -127,7 +127,7 @@ class CanvasExample:
 	label.show()
 
         # Create canvas.
-        self.acanvas = gnome.canvas.Canvas()
+        self.acanvas = gnomecanvas.Canvas()
         self.acanvas.set_size_request(self.width, self.height)
         self.acanvas.set_scroll_region(0,0, self.width, self.height)
         vbox.pack_start(self.acanvas)
